// ===========================================================================
// CONTENT  : INTERFACE IContainer
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 07/01/2007
// HISTORY  :
//  07/01/2007  mdu  CREATED
//
// Copyright (c) 2007, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.odem;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.Collection;

/**
 * Represents a containers that hold types and namespaces.  
 *
 * @author M.Duchrow
 * @version 1.0
 */
public interface IContainer extends IExplorableElement, IStructureVisiting, IAlias
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  /**
   * An empty array of IContainer elements that can be used as return value
   * in implementations whenever an empty array is needed.
   */
  public static final IContainer[] EMPTY_CONTAINER_ARRAY = new IContainer[0];

  // =========================================================================
  // METHODS
  // =========================================================================
  /**
   * Returns the parent container of this container.
   * If this method returns null this is a top-level container.
   */
  public IContainer getParentContainer();

  /**
   * Returns all sub containers of this container.
   * Theis method never returns null. If this container has no sub containers
   * an empty collection will be returned.
   * The result collection is always a copy. That means, manipulating the collection 
   * does not affect the internal state/structure of this container, 
   */
  public Collection<IContainer> getSubContainers();

  /**
   * Returns all namespaces in this container.
   * This method never returns null. If no namespace is contained in the
   * container an empty collection will be returned.
   */
  public Collection<INamespace> getNamespaces();

  /**
   * Returns the classification of this container.
   */
  public ContainerClassification getClassification();

}