// ===========================================================================
// CONTENT  : INTERFACE IObjectProperties
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 12/01/2007
// HISTORY  :
//  12/01/2007  mdu  CREATED
//
// Copyright (c) 2007, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.odem;

/**
 * Each object that supports generic attributes must implement this interface.
 *
 * @author M.Duchrow
 * @version 1.0
 */
public interface IObjectProperties
{
  /**
   * Returns the property associated with the given name. A null value
   * indicates that a property with the specified name does not exist.
   * 
   * @param propertyName A valid name (must not be null or empty string)
   * @return The object associated with the given name or null if property unknown
   */
  public Object getProperty(String propertyName);

  /**
   * Sets the value of the property with the specified name to the given object.
   * This replaces ny object that might have been kept under the given name before.
   * <p/>
   * If the given object is null, the property and any associated value will be
   * removed.
   * 
   * @param propertyName A valid name (must not be null or empty string)
   * @param object The object to keep under the specified property name
   */
  public void setProperty(String propertyName, Object object);

  /**
   * Returns all currently known properties. 
   * If no property is known an empty array will be returned (never null).
   * 
   * @return All the names of available properties 
   */
  public String[] getPropertyNames();
}