// ===========================================================================
// CONTENT  : INTERFACE IStructureVisiting
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 11/01/2007
// HISTORY  :
//  11/01/2007  mdu  CREATED
//
// Copyright (c) 2007, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.odem;

/**
 * Specifies the methods a holder of exploration structures such as namespaces
 * and containers must implement. 
 *
 * @author M.Duchrow
 * @version 1.0
 */
public interface IStructureVisiting extends IExplorableElementVisiting
{
  /**
   * Implementation of the visitor pattern (GOF). 
   * It iterates (recursivly) over all contained IContainer objects and invokes 
   * the visitor's callback method using the containers as parameter.
   * 
   * @param visitor The implementor of the vistor interface to be called by this method
   * @return true if processing should be continued, otherwise false
   */
  public boolean acceptContainers(IContainersVisitor visitor);

  /**
   * Implementation of the visitor pattern (GOF). 
   * It iterates (recursivly) over all contained INamespace objects and invokes 
   * the visitor's callback method using the namespaces as parameter.
   * 
   * @param visitor The implementor of the vistor interface to be called by this method
   * @return true if processing should be continued, otherwise false
   */
  public boolean acceptNamespaces(INamespacesVisitor visitor);

}