// ===========================================================================
// CONTENT  : ENUM TypeClassification
// AUTHOR   : M.Duchrow
// VERSION  : 1.2 - 10/10/2017
// HISTORY  :
//  07/01/2007  mdu  CREATED
//	13/01/2008	mdu		changed	-->	to be based on strings
//
// Copyright (c) 2007-2017, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.odem;

/**
 * Specifies the currently supported types 
 *  
 * @author M.Duchrow
 * @version 1.2
 */
public enum TypeClassification
{
	UNKNOWN("unknown"),
	CLASS("class"),
	INTERFACE("interface"),
	ENUM("enum"),
	ANNOTATION("annotation");
	
  private final String externalName;

  /**
   * Returns the enum value with the given name. If none with that name can 
   * be found null will be returned.
   */
  public static TypeClassification fromString(String valueName)
  {
    for (TypeClassification classification : values())
    {
      if (classification.getExternalName().equals(valueName))
      {
        return classification;
      }
    }
    return null;
  }

  TypeClassification(String str)
  {
    this.externalName = str;
  }

  public String getExternalName()
  {
    return this.externalName;
  }

  /**
   * Returns the external string representation (which is not the same as the enum value name).
   */
  public String asString()
  {
    return this.getExternalName();
  }

  /**
   * Returns a debug string that should not be used in business logic.
   */
  @Override
  public String toString()
  {
    return String.format("%s('%s')", this.name(), this.getExternalName());
  }
} 
